# coding: utf-8

"""
    OurSky SDA

    The basic flow for a new organization is as follows: 1. View the available satellite targets with the [satellite targets](#tag/satellite-targets/[get]/v1/satellite-targets) endpoint. Copy the id of the target you want to observe. 2. Create an organization target with the [organization target](#tag/organization-targets/[get]/v1/organization-targets) endpoint. Use the id copied from above. 3. Create a webhook with the [webhook](#tag/webhooks/[post]/v1/communications/webhook) endpoint to receive TDMs automatically (preferred) or use the [tdms](#tag/tdms/[get]/v1/tdms) endpoint to poll for TDMs.

    The version of the OpenAPI document: 1.3.3750
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional, Union
from pydantic import BaseModel, Field, StrictFloat, StrictInt, StrictStr

class V1TargetCorrelation(BaseModel):
    """
    Target Correlation  # noqa: E501
    """
    target_id: StrictStr = Field(..., alias="targetId")
    ra: Union[StrictFloat, StrictInt] = Field(..., description="The predicted (propagated) center of the targetId in Right Ascension in degrees")
    dec: Union[StrictFloat, StrictInt] = Field(..., description="The predicted (propagated) center of the streak in Declination in degrees")
    streak_length: Optional[Union[StrictFloat, StrictInt]] = Field(None, alias="streakLength", description="The predicted (propagated) length of the target streak in degrees")
    distance_from_streak: Optional[Union[StrictFloat, StrictInt]] = Field(None, alias="distanceFromStreak", description="The distance between the predicted and actual center of the streak in degrees")
    angle_from_streak: Optional[Union[StrictFloat, StrictInt]] = Field(None, alias="angleFromStreak", description="The angle between the predicted and actual angle-to-celestial-north for the streak in degrees")
    __properties = ["targetId", "ra", "dec", "streakLength", "distanceFromStreak", "angleFromStreak"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1TargetCorrelation:
        """Create an instance of V1TargetCorrelation from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1TargetCorrelation:
        """Create an instance of V1TargetCorrelation from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return V1TargetCorrelation.parse_obj(obj)

        _obj = V1TargetCorrelation.parse_obj({
            "target_id": obj.get("targetId"),
            "ra": obj.get("ra"),
            "dec": obj.get("dec"),
            "streak_length": obj.get("streakLength"),
            "distance_from_streak": obj.get("distanceFromStreak"),
            "angle_from_streak": obj.get("angleFromStreak")
        })
        return _obj


