# coding: utf-8

"""
    OurSky SDA

    The basic flow for a new organization is as follows: 1. View the available satellite targets with the [satellite targets](#tag/satellite-targets/[get]/v1/satellite-targets) endpoint. Copy the id of the target you want to observe. 2. Create an organization target with the [organization target](#tag/organization-targets/[get]/v1/organization-targets) endpoint. Use the id copied from above. 3. Create a webhook with the [webhook](#tag/webhooks/[post]/v1/communications/webhook) endpoint to receive TDMs automatically (preferred) or use the [tdms](#tag/tdms/[get]/v1/tdms) endpoint to poll for TDMs.

    The version of the OpenAPI document: 1.3.3750
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class WebhookAuthType(str, Enum):
    """
    Authorization mechanism required for webhook endpoint, if any. Use `NONE` if not required.
    """

    """
    allowed enum values
    """
    NONE = 'NONE'
    BASIC = 'BASIC'
    BEARER = 'BEARER'

    @classmethod
    def from_json(cls, json_str: str) -> WebhookAuthType:
        """Create an instance of WebhookAuthType from a JSON string"""
        return WebhookAuthType(json.loads(json_str))


